<?php
/**
 * Front Style.
 *
 * @package twentig
 */

/**
 * Enqueue scripts and styles.
 */
function twentig_twentyone_theme_scripts() {

	$min = defined( 'SCRIPT_DEBUG' ) && SCRIPT_DEBUG ? '' : '.min';

	wp_enqueue_style(
		'twentig-twentyone',
		TWENTIG_ASSETS_URI . "/css/twentytwentyone{$min}.css",
		array(),
		TWENTIG_VERSION
	);

	wp_style_add_data( 'twentig-twentyone', 'rtl', 'replace' );
	wp_style_add_data( 'twentig-twentyone', 'suffix', $min );

	wp_enqueue_style( // phpcs:ignore WordPress.WP.EnqueuedResourceParameters.MissingVersion
		'twentig-twentyone-fonts',
		twentig_twentyone_fonts_url(),
		array(),
		null
	);

	wp_enqueue_style( // phpcs:ignore WordPress.WP.EnqueuedResourceParameters.MissingVersion
		'twentig-logo-font',
		twentig_twentyone_logo_font_url(),
		array(),
		null
	);

	// Enqueue JavaScript only if header is sticky and this is not an AMP response.
	$header_sticky = get_theme_mod( 'twentig_header_sticky', false );
	if ( $header_sticky && ! twentig_is_amp_endpoint() ) {
		wp_enqueue_script( 'twentig-twentyone', TWENTIG_ASSETS_URI . '/js/twentig-twentytwentyone.js', array(), '1.0', true );
	}
}
add_action( 'wp_enqueue_scripts', 'twentig_twentyone_theme_scripts', 12 );

/**
 * Add preconnect for Google Fonts.
 *
 * @param array  $urls          URLs to print for resource hints.
 * @param string $relation_type The relation type the URLs are printed.
 */
function twentig_twentyone_resource_hints( $urls, $relation_type ) {
	if ( wp_style_is( 'twentig-twentyone-fonts', 'queue' ) && 'preconnect' === $relation_type ) {
		$urls[] = array(
			'href' => 'https://fonts.gstatic.com',
			'crossorigin',
		);
	}
	return $urls;
}
add_filter( 'wp_resource_hints', 'twentig_twentyone_resource_hints', 10, 2 );

/**
 * Add custom classes generated by Customizer settings to the array of body classes.
 *
 * @param array $classes Classes added to the body tag.
 */
function twentig_twentyone_body_class( $classes ) {

	$header_layout     = get_theme_mod( 'twentig_header_layout' );
	$header_background = get_theme_mod( 'twentig_header_background_color' );
	$header_decoration = get_theme_mod( 'twentig_header_decoration' );
	$header_sticky     = get_theme_mod( 'twentig_header_sticky', false );
	$header_breakpoint = get_theme_mod( 'twentig_header_breakpoint', 'mobile' );
	$header_width      = get_theme_mod( 'twentig_header_width' );
	$header_padding    = get_theme_mod( 'twentig_header_padding', 'large' );
	$menu_spacing      = get_theme_mod( 'twentig_menu_spacing' );
	$menu_hover        = get_theme_mod( 'twentig_menu_hover' );
	$footer_layout     = get_theme_mod( 'twentig_footer_layout' );
	$footer_background = get_theme_mod( 'twentig_footer_background_color' );
	$footer_width      = get_theme_mod( 'twentig_footer_width' );
	$widget_background = get_theme_mod( 'twentig_widgets_background_color' );
	$widgets_width     = get_theme_mod( 'twentig_footer_widgets_width' );
	$widgets_columns   = get_theme_mod( 'twentig_footer_widgets_columns' );
	$search_layout     = get_theme_mod( 'twentig_page_search_layout' );
	$link_style        = get_theme_mod( 'twentig_links_style' );
	$button_shape      = get_theme_mod( 'twentig_button_shape', 'square' );
	$border_thickness  = get_theme_mod( 'twentig_border_thickness' );

	if ( $header_layout ) {
		$classes[] = 'tw-header-layout-' . $header_layout;
	}

	if ( 'full' === $header_width ) {
		$classes[] = 'tw-header-full';
	}

	if ( $header_background ) {
		$classes[] = 'tw-header-bg';
	}

	if ( $header_decoration ) {
		$classes[] = 'tw-header-bg';
		$classes[] = 'tw-header-' . $header_decoration;
	}

	if ( $header_sticky ) {
		$classes[] = 'tw-header-sticky';
		$classes[] = 'tw-header-bg';
	}

	if ( $header_breakpoint ) {
		$classes[] = 'tw-header-break-' . $header_breakpoint;
	}

	$classes[] = 'tw-header-padding-' . $header_padding;

	if ( $menu_spacing ) {
		$classes[] = 'tw-nav-spacing-' . $menu_spacing;
	}

	if ( $menu_hover ) {
		$classes[] = 'tw-nav-hover-' . $menu_hover;
	}

	if ( twentig_twentyone_has_sidebar() ) {
		$classes[] = 'tw-has-sidebar';
	}

	if ( $footer_background || twentig_twentyone_has_footer_block_background() ) {
		$classes[] = 'tw-footer-bg';
	}

	if ( 'full' === $footer_width ) {
		$classes[] = 'tw-footer-full';
	}

	if ( is_active_sidebar( 'sidebar-1' ) ) {
		if ( 'full' === $widgets_width ) {
			$classes[] = 'tw-footer-widgets-full';
		}
		if ( $widgets_columns && '3' !== $widgets_columns ) {
			$classes[] = 'tw-footer-widgets-columns-' . $widgets_columns;
		}
		if ( $widget_background || in_array( 'tw-footer-bg', $classes, true ) ) {
			$classes[] = 'tw-footer-widgets-bg';
			if ( $footer_background === $widget_background || ( $footer_background && empty( $widget_background ) ) && 'hidden' !== $footer_layout ) {
				$classes[] = 'tw-footer-monocolor';
			}
		}
	} elseif ( 'hidden' === $footer_layout ) {
		$classes[] = 'tw-no-footer';
	}

	if ( $link_style ) {
		$classes[] = 'tw-link-' . $link_style;
		$classes   = array_diff( $classes, array( 'has-background-white' ) );

		if ( in_array( 'is-dark-theme', $classes, true ) ) {
			$classes   = array_diff( $classes, array( 'is-dark-theme' ) );
			$classes[] = 'dark-theme';
		}
	}

	if ( 'square' !== $button_shape ) {
		$classes[] = 'tw-btn-' . $button_shape;
	}

	if ( is_home() || is_author() || is_category() || is_tag() || is_date() || is_tax( get_object_taxonomies( 'post' ) )
		|| ( is_search() && 'blog-layout' === $search_layout ) ) {

		$blog_layout     = get_theme_mod( 'twentig_blog_layout', 'stack' );
		$blog_style      = get_theme_mod( 'twentig_blog_style', 'separator' );
		$blog_image      = get_theme_mod( 'twentig_blog_image', true );
		$image_width     = get_theme_mod( 'twentig_blog_image_width', 'wide' );
		$image_placement = get_theme_mod( 'twentig_blog_image_placement', 'below' );
		$image_ratio     = get_theme_mod( 'twentig_blog_image_ratio' );
		$blog_pagination = get_theme_mod( 'twentig_blog_pagination' );
		$heading_size    = get_theme_mod( 'twentig_blog_title_size' );

		$classes[] = 'tw-blog-' . $blog_layout;

		if ( 'grid' === $blog_layout ) {
			$classes[] = 'tw-blog-columns-' . get_theme_mod( 'twentig_blog_columns', '3' );
			add_filter(
				'post_thumbnail_size',
				function() {
					return 'medium_large';
				}
			);
			twentig_twentyone_remove_image_inline_size_style();
		}

		if ( $blog_style ) {
			if ( in_array( $blog_style, array( 'card-shadow', 'card-border' ), true ) ) {
				$classes[] = 'tw-blog-card';
			}
			$classes[] = 'tw-blog-' . $blog_style;
		}

		if ( $blog_image ) {
			$classes[] = 'tw-blog-image-' . $image_width;
			$classes[] = 'tw-blog-image-' . $image_placement;
			if ( $image_ratio ) {
				$classes[] = 'tw-blog-img-ratio-' . $image_ratio;
				twentig_twentyone_remove_image_inline_size_style();
			}
		}

		if ( 'center' === get_theme_mod( 'twentig_blog_text_align' ) ) {
			$classes[] = 'tw-blog-text-center';
		}

		if ( $heading_size ) {
			$classes[] = 'tw-blog-title-size-' . $heading_size;
		}

		if ( ! get_theme_mod( 'twentig_blog_content', true ) ) {
			$classes[] = 'tw-blog-no-content';
		}

		if ( $blog_pagination ) {
			$classes[] = 'tw-blog-pagination-' . $blog_pagination;
		}
	} elseif ( is_search() ) {
		$blog_pagination = get_theme_mod( 'twentig_blog_pagination' );
		if ( $blog_pagination ) {
			$classes[] = 'tw-blog-pagination-' . $blog_pagination;
		}
	} elseif ( is_page() ) {

		$hero_layout     = get_theme_mod( 'twentig_page_hero_layout', '' );
		$title_center    = get_theme_mod( 'twentig_page_title_text_align', false );
		$title_width     = get_theme_mod( 'twentig_page_title_width', 'wide' );
		$title_border    = get_theme_mod( 'twentig_page_title_border', true );
		$image_placement = get_theme_mod( 'twentig_page_image_placement', 'below' );

		if ( has_post_thumbnail() && ! is_page_template() ) {

			if ( $hero_layout ) {
				$classes[] = 'tw-hero-' . $hero_layout;
			}

			if ( in_array( $hero_layout, array( '', 'narrow-image', 'full-image' ), true ) ) {
				$classes[] = 'tw-hero-' . $image_placement;
			}

			if ( 'cover-full' === $hero_layout ) {
				$classes[] = 'tw-hero-cover';
			}

			if ( in_array( $hero_layout, array( 'cover', 'cover-full' ), true ) ) {
				twentig_twentyone_remove_image_inline_size_style();
			}
		}

		if ( 'text-width' === $title_width ) {
			$classes[] = 'tw-title-text-width';
		}

		if ( $title_center ) {
			$classes[] = 'tw-title-center';
		}

		if ( ! $title_border ) {
			$classes[] = 'tw-title-no-border';
		}

		if ( comments_open() || get_comments_number() && ! post_password_required() ) {
			$classes[] = 'tw-showing-comments';
		}
	} elseif ( is_singular( 'post' ) ) {

		$hero_layout     = get_theme_mod( 'twentig_post_hero_layout', '' );
		$title_center    = get_theme_mod( 'twentig_post_title_text_align', false );
		$title_width     = get_theme_mod( 'twentig_post_title_width', 'wide' );
		$title_border    = get_theme_mod( 'twentig_post_title_border', true );
		$image_placement = get_theme_mod( 'twentig_post_image_placement', 'below' );

		if ( has_post_thumbnail() ) {

			if ( $hero_layout ) {
				$classes[] = 'tw-hero-' . $hero_layout;
			}

			if ( in_array( $hero_layout, array( '', 'narrow-image', 'full-image' ), true ) ) {
				$classes[] = 'tw-hero-' . $image_placement;
			}

			if ( 'cover-full' === $hero_layout ) {
				$classes[] = 'tw-hero-cover';
			}

			if ( in_array( $hero_layout, array( 'cover', 'cover-full' ), true ) ) {
				twentig_twentyone_remove_image_inline_size_style();
			}
		}

		if ( 'text-width' === $title_width ) {
			$classes[] = 'tw-title-text-width';
		}

		if ( $title_center ) {
			$classes[] = 'tw-title-center';
		}

		if ( ! $title_border ) {
			$classes[] = 'tw-title-no-border';
		}
	}

	if ( ! in_array( 'tw-header-bg', $classes, true ) && ( in_array( 'tw-hero-cover', $classes, true ) || in_array( 'page-template-tw-header-transparent', $classes, true ) || in_array( 'page-template-tw-header-transparent-light', $classes, true ) ) ) {
		$classes[] = 'tw-header-bg';
	}

	if ( in_array( 'tw-hero-cover', $classes, true ) || in_array( 'page-template-tw-header-transparent-light', $classes, true ) ) {
		$classes[] = 'tw-header-light';
	}

	if ( twentig_is_amp_endpoint() && in_array( 'tw-header-light', $classes, true ) && in_array( 'tw-header-sticky', $classes, true ) ) {
		$classes[] = 'tw-header-opaque';
	}

	if ( 'thin' === $border_thickness ) {
		$classes[] = 'tw-border-thin';
	}

	return $classes;
}
add_filter( 'body_class', 'twentig_twentyone_body_class', 11 );

/**
 * Display custom CSS generated by the Customizer settings.
 */
function twentig_twentyone_print_customizer_css() {

	$wide_width              = get_theme_mod( 'twentig_wide_width' );
	$default_width           = get_theme_mod( 'twentig_default_width' );
	$body_font               = get_theme_mod( 'twentig_body_font' );
	$body_font_size          = get_theme_mod( 'twentig_body_font_size', 20 );
	$body_line_height        = get_theme_mod( 'twentig_body_line_height', 1.7 );
	$heading_font            = get_theme_mod( 'twentig_heading_font' );
	$heading_font_weight     = get_theme_mod( 'twentig_heading_font_weight', '400' );
	$heading_letter_spacing  = get_theme_mod( 'twentig_heading_letter_spacing', 0 );
	$tertiary_font           = get_theme_mod( 'twentig_secondary_elements_font', 'body' );
	$menu_font               = get_theme_mod( 'twentig_menu_font', 'body' );
	$menu_letter_spacing     = get_theme_mod( 'twentig_menu_letter_spacing', 0 );
	$show_site_title         = get_theme_mod( 'display_title_and_tagline', true );
	$h1_font_size            = get_theme_mod( 'twentig_h1_font_size', 96 );
	$post_h1_font_size       = get_theme_mod( 'twentig_post_h1_font_size' );
	$menu_font_size          = get_theme_mod( 'twentig_menu_font_size' );
	$menu_font_weight        = get_theme_mod( 'twentig_menu_font_weight', 400 );
	$logo_font_size          = get_theme_mod( 'twentig_logo_font_size' );
	$logo_mobile_font_size   = get_theme_mod( 'twentig_logo_font_size_mobile' );
	$button_text_transform   = get_theme_mod( 'twentig_button_text_transform' );
	$button_text_color       = get_theme_mod( 'twentig_button_text_color' );
	$button_background       = get_theme_mod( 'twentig_button_background_color' );
	$button_hover_background = get_theme_mod( 'twentig_button_hover_background_color' );
	$css                     = '';
	$css_mobile              = '';
	$css_var                 = ':root{';

	if ( $wide_width ) {
		$css_var .= '--max--alignwide-width:' . twentig_twentyone_generate_value( $wide_width );
	}

	if ( $default_width ) {
		$css_var .= '--max--aligndefault-width:' . twentig_twentyone_generate_value( $default_width );
	}

	if ( $body_font ) {
		$css_var .= '--font-base:' . $body_font . ';';
	}

	if ( $body_font_size ) {
		$css_var .= '--global--font-size-base:' . twentig_twentyone_generate_value( $body_font_size, 'rem' );
		if ( $body_font_size > 20 ) {
			$css_mobile .= ':root { --global--font-size-base: 1.25rem; }';
		}
	}

	if ( $body_line_height && 1.7 !== $body_line_height ) {
		$css_var .= '--global--line-height-body:' . $body_line_height . ';';
	}

	if ( $heading_font ) {
		$css_var .= '--font-headings:' . $heading_font . ';';
		if ( $heading_font_weight ) {
			$css_var .= '--heading--font-weight:' . $heading_font_weight . ';';
			$css_var .= '--heading--font-weight-page-title:' . $heading_font_weight . ';';
			$css_var .= '--heading--font-weight-strong:' . $heading_font_weight . ';';
		}
	} elseif ( '400' !== $heading_font_weight ) {
		$css_var .= '--heading--font-weight:' . $heading_font_weight . ';';
		$css_var .= '--heading--font-weight-page-title:' . $heading_font_weight . ';';
		$css_var .= '--heading--font-weight-strong:' . $heading_font_weight . ';';
	}

	if ( ! empty( $heading_letter_spacing ) ) {
		$css_var .= '--global--letter-spacing:' . twentig_twentyone_generate_value( $heading_letter_spacing, 'em' );
		$css_var .= '--heading--letter-spacing-h5:' . twentig_twentyone_generate_value( $heading_letter_spacing, 'em' );
		$css_var .= '--heading--letter-spacing-h6:' . twentig_twentyone_generate_value( $heading_letter_spacing, 'em' );
	}

	if ( $h1_font_size && 96 !== $h1_font_size ) {
		$css_var .= '--global--font-size-xxl:' . twentig_twentyone_generate_value( $h1_font_size, 'rem' );
	}

	if ( 'heading' === $tertiary_font ) {
		$css_var .= '--global--font-tertiary: var(--font-headings);';
	}

	if ( 'heading' === $menu_font ) {
		$css_var .= '--primary-nav--font-family: var(--font-headings);';
	}

	if ( $menu_font_size ) {
		$css_var .= '--primary-nav--font-size:' . twentig_twentyone_generate_value( $menu_font_size, 'rem' );
	}

	if ( $menu_font_weight ) {
		$css_var .= '--primary-nav--font-weight:' . $menu_font_weight . ';';
	}

	if ( ! empty( $menu_letter_spacing ) ) {
		$css_var .= '--primary-nav--letter-spacing:' . twentig_twentyone_generate_value( $menu_letter_spacing, 'em' );
	}

	if ( $show_site_title ) {
		if ( $logo_font_size ) {
			$css_var .= '--branding--title--font-size:' . twentig_twentyone_generate_value( $logo_font_size );
		}

		if ( $logo_mobile_font_size ) {
			$css_var .= '--branding--title--font-size-mobile:' . twentig_twentyone_generate_value( $logo_mobile_font_size );
		} elseif ( $logo_font_size ) {
			$css_var .= '--branding--title--font-size-mobile:' . twentig_twentyone_generate_value( $logo_font_size );
		}
	}

	if ( 'uppercase' === $button_text_transform ) {
		$css_var .= '--button--font-size: var(--global--font-size-xs);';
	}

	$css_var .= twentig_twentyone_generate_color_variables();

	$css_var .= '}';

	$css .= $css_var;

	if ( $post_h1_font_size ) {
		$css .= '@media( min-width:822px ) { .single-post { --global--font-size-page-title:' . twentig_twentyone_generate_value( $post_h1_font_size, 'rem' ) . '} }';
	}

	/* Site title */
	if ( $show_site_title ) {
		$css_logo            = '';
		$logo_font           = get_theme_mod( 'twentig_logo_font' );
		$logo_font_weight    = get_theme_mod( 'twentig_logo_font_weight', '400' );
		$logo_letter_spacing = get_theme_mod( 'twentig_logo_letter_spacing', false );
		$logo_transform      = get_theme_mod( 'twentig_logo_text_transform', 'uppercase' );

		if ( $logo_font ) {
			$css_logo .= 'font-family: ' . $logo_font . ';';
		}

		if ( $logo_font_weight ) {
			$css_logo .= 'font-weight: ' . $logo_font_weight . ';';
		}

		if ( $logo_letter_spacing ) {
			$css_logo .= 'letter-spacing:' . twentig_twentyone_generate_value( $logo_letter_spacing, 'em' );
		}

		if ( $logo_transform ) {
			$css_logo .= 'text-transform: ' . esc_attr( $logo_transform ) . ';';
		}

		if ( $css_logo ) {
			$css .= '.site-header .site-title, .site-footer > .site-info .site-name {' . $css_logo . '}';
		}
	}

	/* Logo */
	if ( has_custom_logo() ) {
		$logo                 = wp_get_attachment_image_src( get_theme_mod( 'custom_logo' ), 'full' );
		$logo_width           = esc_attr( $logo[1] );
		$logo_height          = esc_attr( $logo[2] );
		$logo_maxwidth        = get_theme_mod( 'twentig_logo_width' );
		$logo_mobile_maxwidth = get_theme_mod( 'twentig_logo_width_mobile' );

		if ( empty( $logo_maxwidth ) && empty( $logo_mobile_maxwidth ) ) {
			$logo_mobile_maxwidth = 96;
		}

		if ( $logo_maxwidth ) {
			$css               .= '.site-logo .custom-logo { max-width:' . twentig_twentyone_generate_value( $logo_maxwidth ) . 'max-height: none !important; }';
			$logo_visual_height = min( $logo_maxwidth, $logo_width ) * $logo_height / $logo_width;
		} else {
			$logo_visual_height = min( 100, min( 300, $logo_width ) * $logo_height / $logo_width );
		}
		if ( $logo_mobile_maxwidth ) {
			$css_mobile               .= '.site-logo .custom-logo { max-width:' . twentig_twentyone_generate_value( $logo_mobile_maxwidth ) . 'max-height: none !important; }';
			$logo_visual_height_mobile = min( $logo_mobile_maxwidth, $logo_width ) * $logo_height / $logo_width;
		} else {
			$logo_visual_height_mobile = $logo_visual_height;
		}

		$css .= ':root{ --logo--height:' . round( $logo_visual_height, 2 ) . 'px; --logo--height-mobile:' . round( $logo_visual_height_mobile, 2 ) . 'px; }';
	}

	/* Menu */

	$menu_transform = get_theme_mod( 'twentig_menu_text_transform' );

	if ( $menu_transform ) {
		$css .= '.primary-navigation, .menu-button-container .button { text-transform:' . esc_attr( $menu_transform ) . '; }';
	}

	/* Minimal Link */
	if ( 'minimal' === get_theme_mod( 'twentig_footer_link_style' ) ) {
		$css .= '.site-footer a, .widget-area a { text-decoration: none; } 
		.site-footer a:hover, .widget-area a:hover, .site-footer a:focus, .widget-area a:focus { text-decoration: underline; }
		.footer-navigation-wrapper li a:hover{ text-decoration-style: solid; }';
	}

	/* Subtle Color */

	$subtle_background = get_theme_mod( 'twentig_subtle_background_color' );
	if ( $subtle_background ) {
		$css .= ':root .has-subtle-background-color, :root .has-subtle-background-background-color{ background-color: ' . $subtle_background . '; }';
		$css .= ':root .has-subtle-color{ color: ' . $subtle_background . '; }';
	}

	if ( twentig_twentyone_is_light_theme() && 36 > Twenty_Twenty_One_Custom_Colors::get_relative_luminance_from_hex( get_theme_mod( 'twentig_primary_color' ) ) ) {
		$css .= ':not(.has-text-color).has-green-background-color[class],
		:not(.has-text-color).has-blue-background-color[class],
		:not(.has-text-color).has-purple-background-color[class],
		:not(.has-text-color).has-red-background-color[class],
		:not(.has-text-color).has-orange-background-color[class],
		:not(.has-text-color).has-yellow-background-color[class] { 
			color: var(--global--color-primary); 
		}';
	}

	/* Footer */
	$footer_link_color = get_theme_mod( 'twentig_footer_link_color' );
	if ( $footer_link_color ) {
		$css .= '.footer-custom a { color: var(--footer--color-link); }';
	}

	/* Button */

	if ( 'uppercase' === $button_text_transform ) {
		$css .= 'input[type="submit"],
		.wp-block-button__link,
		.wp-block-file__button,
		.wp-block-search__button,
		.primary-navigation .header-actions li.menu-button a { 
			text-transform:uppercase; letter-spacing: 0.05em;
		}';
	}

	if ( $button_background ) {
		$css .= '
		.site .site-content input[type=submit],
		.site .wp-block-button:not(.is-style-outline) .wp-block-button__link:not(.has-background),
		.site .wp-block-file .wp-block-file__button { 
			background-color:' . $button_background . ';
			border-color:' . $button_background . ';';
		if ( $button_text_color ) {
			$css .= 'color:' . $button_text_color . ';';
		}
		$css .= '}';

		$css .= '.site .wp-block-button.is-style-outline .wp-block-button__link:not(.has-text-color) { 
			border-color:' . $button_background . ';
			color:' . $button_background . ';
		}';

		$header_background = get_theme_mod( 'twentig_header_background_color' );
		if ( $header_background !== $button_background ) {
			$css .= '
			#page .primary-navigation .menu-button a,
			#page .primary-navigation .menu-button a:focus { 
				background-color:' . $button_background . ';';
			if ( $button_text_color ) {
				$css .= 'color:' . $button_text_color . ';';
			}
			$css .= '}';
		}

		if ( $button_hover_background ) {
			$css .= '
			.site .site-content input[type=submit]:hover,
			.site .site-content input[type=submit]:focus,
			.site .site-content input[type=submit]:active,
			.site .wp-block-button:not(.is-style-outline) .wp-block-button__link:not(.has-background):hover,
			.site .wp-block-button:not(.is-style-outline) .wp-block-button__link:not(.has-background):focus,
			.site .wp-block-button:not(.is-style-outline) .wp-block-button__link:not(.has-background):active,
			.site .wp-block-button.is-style-outline .wp-block-button__link:not(.has-text-color):hover,
			.site .wp-block-button.is-style-outline .wp-block-button__link:not(.has-text-color):focus,
			.site .wp-block-button.is-style-outline .wp-block-button__link:not(.has-text-color):active,
			.site .wp-block-file .wp-block-file__button:hover,
			.site .wp-block-file .wp-block-file__button:focus,
			.site .wp-block-file .wp-block-file__button:active { 
				background-color:' . $button_hover_background . ' !important;
				border-color:' . $button_hover_background . ' !important;';
			if ( $button_text_color ) {
				$css .= 'color:' . $button_text_color . ' !important;';
			}
			$css .= '}';

			if ( $header_background !== $button_background ) {
				$css .= '
				#page .primary-navigation .menu-button a:hover,
				#page .primary-navigation .menu-button a:focus { 
					opacity: 1; 
					background-color:' . $button_hover_background . ' !important;';
				if ( $button_text_color ) {
					$css .= 'color:' . $button_text_color . ' !important;';
				}
				$css .= '}';
			}
		} else {
			$css .= '
			.site .site-content input[type=submit]:hover,
			.site .site-content input[type=submit]:focus,
			.site .site-content input[type=submit]:active,
			.site .wp-block-button:not(.is-style-outline) .wp-block-button__link:not(.has-background):hover,
			.site .wp-block-button:not(.is-style-outline) .wp-block-button__link:not(.has-background):focus,
			.site .wp-block-button:not(.is-style-outline) .wp-block-button__link:not(.has-background):active,
			.site .wp-block-file .wp-block-file__button:hover,
			.site .wp-block-file .wp-block-file__button:focus,
			.site .wp-block-file .wp-block-file__button:active { 
				background-color: transparent !important;
				border-color:' . $button_background . ' !important;
				color:' . $button_background . ' !important;';
			$css .= '}';

			$css .= '
			.site .wp-block-button.is-style-outline .wp-block-button__link:not(.has-text-color):hover,
			.site .wp-block-button.is-style-outline .wp-block-button__link:not(.has-text-color):focus,
			.site .wp-block-button.is-style-outline .wp-block-button__link:not(.has-text-color):active {
				border-color: transparent;
				background-color:' . $button_background . ' !important;';
			if ( $button_text_color ) {
				$css .= 'color:' . $button_text_color . ' !important;';
			}
			$css .= '}';
		}
	}

	if ( $css_mobile ) {
		$css .= '@media( max-width:651px ) {' . $css_mobile . '}';
	}

	$css = apply_filters( 'twentig_twentyone_custom_css', $css );

	if ( $css ) :
		?>
	<style type="text/css" id="twentig-twentyone-custom-css">
		<?php echo twentig_minify_css( $css ); // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped ?>
	</style>

		<?php
	endif;
}
add_action( 'wp_head', 'twentig_twentyone_print_customizer_css' );

/**
 * Genrate CSS value with its unit.
 *
 * @param string $value The CSS value.
 * @param string $unit The CSS unit.
 */
function twentig_twentyone_generate_value( $value, $unit = 'px' ) {
	if ( 'rem' === $unit ) {
		return intval( $value ) / 16 . 'rem;';
	} elseif ( 'em' === $unit ) {
		return floatval( $value ) . 'em;';
	}
	return intval( $value ) . 'px;';
}

/**
 * Remove image inline size style.
 */
function twentig_twentyone_remove_image_inline_size_style() {
	remove_filter( 'wp_get_attachment_image_attributes', 'twenty_twenty_one_get_attachment_image_attributes' );
}


/**
 * Detects if a sidebar is displayed.
 */
function twentig_twentyone_has_sidebar() {
	if (
		is_active_sidebar( 'sidebar-blog' ) && (
		( get_theme_mod( 'twentig_blog_sidebar', false ) && ( is_home() || is_author() || is_category() || is_tag() || is_date() || is_tax( get_object_taxonomies( 'post' ) ) || ( is_search() && 'blog-layout' === get_theme_mod( 'twentig_page_search_layout' ) ) ) )
		|| ( get_theme_mod( 'twentig_post_sidebar', false ) && is_singular( 'post' ) )
		)
	) {
		return true;
	}
	return false;
}

/**
 * Add custom image sizes attribute to enhance responsive image functionality.
 *
 * @param string $sizes A source size value for use in a 'sizes' attribute.
 */
function twentig_twentyone_calculate_image_sizes( $sizes ) {

	$wide_width    = get_theme_mod( 'twentig_wide_width', 1240 );
	$wide_width    = $wide_width ? $wide_width : 1240;
	$default_width = get_theme_mod( 'twentig_default_width', 610 );
	$default_width = $default_width ? $default_width : 610;
	$search_layout = get_theme_mod( 'twentig_page_search_layout' );
	$has_sidebar   = twentig_twentyone_has_sidebar();

	if ( is_home() || is_author() || is_category() || is_tag() || is_date() || is_tax( get_object_taxonomies( 'post' ) )
		|| ( is_search() && 'blog-layout' === $search_layout )
	) {

		$blog_layout = get_theme_mod( 'twentig_blog_layout' );
		$image_width = get_theme_mod( 'twentig_blog_image_width', 'wide' );
		$blog_style  = get_theme_mod( 'twentig_blog_style', 'separator' );

		if ( $has_sidebar ) {
			if ( 'grid' === $blog_layout ) {
				$blog_columns = get_theme_mod( 'twentig_blog_columns', '3' );
				if ( '2' === $blog_columns ) {
					$sizes = '(min-width: 1280px) ' . intval( ( $wide_width - 440 ) / 2 ) . 'px, (min-width: 1024px) calc(50vw - 242px), (min-width: 652px) ' . intval( $default_width / 2 - 12 ) . 'px, (min-width: 482px) calc(100vw - 80px), calc(100vw - 40px)';
				} else {
					$sizes = '(min-width: 1280px) ' . intval( ( $wide_width - 480 ) / 3 ) . 'px, (min-width: 1024px) calc(50vw - 242px), (min-width: 652px) ' . intval( $default_width / 2 - 12 ) . 'px, (min-width: 482px) calc(100vw - 80px), calc(100vw - 40px)';
				}
			} else {
				$sizes = '(min-width: 1280px) ' . intval( $wide_width - 400 ) . 'px, (min-width: 1024px) calc(100vw - 460px), (min-width: 652px) ' . intval( $default_width ) . 'px, (min-width: 482px) calc(100vw - 80px), calc(100vw - 40px)';
			}
		} else {
			if ( 'grid' === $blog_layout ) {
				$blog_columns = get_theme_mod( 'twentig_blog_columns', '3' );
				if ( '2' === $blog_columns ) {
					$sizes = '(min-width: 1280px) ' . intval( $wide_width / 2 - 20 ) . 'px, (min-width: 822px) calc(50vw - 80px), (min-width: 652px) calc(50vw - 52px), (min-width: 482px) calc(100vw - 80px), calc(100vw - 40px)';
				} else {
					$sizes = '(min-width: 1280px) ' . intval( $wide_width / 3 - 27 ) . 'px, (min-width: 822px) calc(50vw - 80px), (min-width: 652px) calc(50vw - 52px), (min-width: 482px) calc(100vw - 80px), calc(100vw - 40px)';
				}
			} else {
				if ( 'text-width' === $image_width || 'card-shadow' === $blog_style || 'card-border' === $blog_style ) {
					$sizes = '(min-width: 652px) ' . intval( $default_width ) . 'px, (min-width: 482px) calc(100vw - 80px), calc(100vw - 40px)';
				} else {
					$sizes = '(min-width: 1280px) ' . intval( $wide_width ) . 'px, (min-width: 822px) calc(100vw - 120px), (min-width: 482px) calc(100vw - 80px), calc(100vw - 40px)';
				}
			}
		}
	} elseif ( is_singular( array( 'post', 'page' ) ) && ! is_page_template() ) {
		$hero_layout = is_page() ? get_theme_mod( 'twentig_page_hero_layout' ) : get_theme_mod( 'twentig_post_hero_layout' );

		if ( $has_sidebar ) {
			$sizes = '(min-width: 1280px) ' . intval( $wide_width - 400 ) . 'px, (min-width: 1024px) calc(100vw - 460px), (min-width: 652px) ' . intval( $default_width ) . 'px, (min-width: 482px) calc(100vw - 80px), calc(100vw - 40px)';
		} elseif ( in_array( $hero_layout, array( 'full-image', 'cover', 'cover-full' ), true ) ) {
			$sizes = '100vw';
		} elseif ( 'narrow-image' === $hero_layout ) {
			$sizes = '(min-width: 652px) ' . intval( $default_width ) . 'px, (min-width: 482px) calc(100vw - 80px), calc(100vw - 40px)';
		} else {
			$sizes = '(min-width: 1280px) ' . intval( $wide_width ) . 'px, (min-width: 822px) calc(100vw - 120px), (min-width: 482px) calc(100vw - 80px), calc(100vw - 40px)';
		}
	}
	return $sizes;
}
add_filter( 'wp_calculate_image_sizes', 'twentig_twentyone_calculate_image_sizes' );
